==> jc-1.4.0.tar.gz: javax/crypto/spec/DHGenParameterSpec.h <==
// public class javax.crypto.spec.DHGenParameterSpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d1748415783540b javax_crypto_spec_DHGenParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_DHGenParameterSpec_H_
#define _JC_javax_crypto_spec_DHGenParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_DHGenParameterSpec$sub_refs	_jc_javax_crypto_spec_DHGenParameterSpec$sub_refs;
typedef struct _jc_javax_crypto_spec_DHGenParameterSpec$sub_nonrefs	_jc_javax_crypto_spec_DHGenParameterSpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_DHGenParameterSpec$refs	_jc_javax_crypto_spec_DHGenParameterSpec$refs;
typedef struct _jc_javax_crypto_spec_DHGenParameterSpec$nonrefs	_jc_javax_crypto_spec_DHGenParameterSpec$nonrefs;
typedef struct _jc_javax_crypto_spec_DHGenParameterSpec$object	_jc_javax_crypto_spec_DHGenParameterSpec$object;

typedef const struct _jc_javax_crypto_spec_DHGenParameterSpec$vmethods	_jc_javax_crypto_spec_DHGenParameterSpec$vmethods;
typedef const struct _jc_javax_crypto_spec_DHGenParameterSpec$vtable	_jc_javax_crypto_spec_DHGenParameterSpec$vtable;
typedef const struct _jc_javax_crypto_spec_DHGenParameterSpec$vtype	_jc_javax_crypto_spec_DHGenParameterSpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_DHGenParameterSpec$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_javax_crypto_spec_DHGenParameterSpec$object *, jint, jint);

// Virtual methods
extern jint _jc_javax_crypto_spec_DHGenParameterSpec$method$getExponentSize$5b12d3ab8d65d4ee(_jc_env *, struct _jc_javax_crypto_spec_DHGenParameterSpec$object *);
extern jint _jc_javax_crypto_spec_DHGenParameterSpec$method$getPrimeSize$3398cd7160228783(_jc_env *, struct _jc_javax_crypto_spec_DHGenParameterSpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_DHGenParameterSpec$method_info$getExponentSize$5b12d3ab8d65d4ee;
extern _jc_method _jc_javax_crypto_spec_DHGenParameterSpec$method_info$getPrimeSize$3398cd7160228783;

// Virtual methods structure
struct _jc_javax_crypto_spec_DHGenParameterSpec$vmethods {
	jint	(*getExponentSize$5b12d3ab8d65d4ee)(_jc_env *, struct _jc_javax_crypto_spec_DHGenParameterSpec$object *);
	jint	(*getPrimeSize$3398cd7160228783)(_jc_env *, struct _jc_javax_crypto_spec_DHGenParameterSpec$object *);
};

// Vtable
struct _jc_javax_crypto_spec_DHGenParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_DHGenParameterSpec$vmethods	javax_crypto_spec_DHGenParameterSpec;
};

// Vtype
struct _jc_javax_crypto_spec_DHGenParameterSpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_DHGenParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHGenParameterSpec$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_DHGenParameterSpec$refs {
    _jc_javax_crypto_spec_DHGenParameterSpec$sub_refs	javax_crypto_spec_DHGenParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHGenParameterSpec$sub_nonrefs {
	jint	primeSize;
	jint	exponentSize;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_DHGenParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_DHGenParameterSpec$sub_nonrefs	javax_crypto_spec_DHGenParameterSpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_DHGenParameterSpec$object {
	_jc_javax_crypto_spec_DHGenParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_DHGenParameterSpec$vtype	*vtype;
	_jc_javax_crypto_spec_DHGenParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_DHGenParameterSpec$vtype _jc_javax_crypto_spec_DHGenParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_DHGenParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_DHGenParameterSpec$class_object;

#endif	/* _JC_javax_crypto_spec_DHGenParameterSpec_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/spec/DHGenParameterSpec.h <==
// public class javax.crypto.spec.DHGenParameterSpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d1748415783540b javax_crypto_spec_DHGenParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_DHGenParameterSpec_H_
#define _JC_javax_crypto_spec_DHGenParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_DHGenParameterSpec$sub_refs	_jc_javax_crypto_spec_DHGenParameterSpec$sub_refs;
typedef struct _jc_javax_crypto_spec_DHGenParameterSpec$sub_nonrefs	_jc_javax_crypto_spec_DHGenParameterSpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_DHGenParameterSpec$refs	_jc_javax_crypto_spec_DHGenParameterSpec$refs;
typedef struct _jc_javax_crypto_spec_DHGenParameterSpec$nonrefs	_jc_javax_crypto_spec_DHGenParameterSpec$nonrefs;
typedef struct _jc_javax_crypto_spec_DHGenParameterSpec$object	_jc_javax_crypto_spec_DHGenParameterSpec$object;

typedef const struct _jc_javax_crypto_spec_DHGenParameterSpec$vmethods	_jc_javax_crypto_spec_DHGenParameterSpec$vmethods;
typedef const struct _jc_javax_crypto_spec_DHGenParameterSpec$vtable	_jc_javax_crypto_spec_DHGenParameterSpec$vtable;
typedef const struct _jc_javax_crypto_spec_DHGenParameterSpec$vtype	_jc_javax_crypto_spec_DHGenParameterSpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_DHGenParameterSpec$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_javax_crypto_spec_DHGenParameterSpec$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_crypto_spec_DHGenParameterSpec$method$getExponentSize$5b12d3ab8d65d4ee(_jc_env *, struct _jc_javax_crypto_spec_DHGenParameterSpec$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_spec_DHGenParameterSpec$method$getPrimeSize$3398cd7160228783(_jc_env *, struct _jc_javax_crypto_spec_DHGenParameterSpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_DHGenParameterSpec$method_info$getExponentSize$5b12d3ab8d65d4ee;
extern _jc_method _jc_javax_crypto_spec_DHGenParameterSpec$method_info$getPrimeSize$3398cd7160228783;

// Virtual methods structure
struct _jc_javax_crypto_spec_DHGenParameterSpec$vmethods {
	jint	(*getExponentSize$5b12d3ab8d65d4ee)(_jc_env *, struct _jc_javax_crypto_spec_DHGenParameterSpec$object *) _JC_JCNI_ATTR;
	jint	(*getPrimeSize$3398cd7160228783)(_jc_env *, struct _jc_javax_crypto_spec_DHGenParameterSpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_spec_DHGenParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_DHGenParameterSpec$vmethods	javax_crypto_spec_DHGenParameterSpec;
};

// Vtype
struct _jc_javax_crypto_spec_DHGenParameterSpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_DHGenParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHGenParameterSpec$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_DHGenParameterSpec$refs {
    _jc_javax_crypto_spec_DHGenParameterSpec$sub_refs	javax_crypto_spec_DHGenParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHGenParameterSpec$sub_nonrefs {
	jint	primeSize;
	jint	exponentSize;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_DHGenParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_DHGenParameterSpec$sub_nonrefs	javax_crypto_spec_DHGenParameterSpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_DHGenParameterSpec$object {
	_jc_javax_crypto_spec_DHGenParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_DHGenParameterSpec$vtype	*vtype;
	_jc_javax_crypto_spec_DHGenParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_DHGenParameterSpec$vtype _jc_javax_crypto_spec_DHGenParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_DHGenParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_DHGenParameterSpec$class_object;

#endif	/* _JC_javax_crypto_spec_DHGenParameterSpec_H_ */
